package com.caimei.module.product.service;

import com.caimei.module.base.entity.bo.PageVo;
import com.caimei.module.base.entity.po.SeconHandProduct;
import com.caimei.module.base.entity.vo.*;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2020/3/25
 */
public interface ProductModuleService {
    /**
     * 商品分类
     */
    List<BigtypeVo> getClassify(String domain, String typeSort, String source);

    /**
     * 根据分类ID获取分类列表
     * @return
     */
    BigtypeVo getClassifyByTypeId(String domain, Integer typeId, Integer idType, String source);

    /**
     * 根据一级分类ID获取二三级分类
     */
    List<SmalltypeVo> getBigTypeClassify(String domain, Integer bigTypeID, String source);

    /**
     * 根据一级/二级/三级分类获取商品
     */
    PageVo<ProductVo> getProductsByTypeId(Integer bigTypeID, Integer smallTypeID, Integer tinyTypeID, Integer sortType, String source, Integer pageNum, Integer pageSize);

    /**
     * 根据关键词获取商品
     */
    PageVo<ProductVo> searchProduct(String searchWord, Integer userId, Integer pageNum, Integer pageSize);

    /**
     * 商品搜索历史记录
     */
    List<SearchHistoryVo> getSearchHistory(Integer userId);

    /**
     * 根据用户ID删除历史记录
     */
    void deleteAllSearchHistory(Integer userId);

    /**
     * 商品详情页
     */
    ProductVo getProductDetails(Integer productID, String domain);

    /**
     * 设置商品展示价格
     */
    ProductVo getShowPrice(ProductVo product, Integer userId);

    /**
     * 获取阶梯价格
     */
    List<LadderPriceVo> findLadderPrice(Integer productID);

    /**
     * 获取一条最低阶梯价格
     */
    LadderPriceVo findLowerLadderPrice(Integer productID);

    /**
     * 获取模块商品列表
     *
     * @param preferredFlag 新品上线(001) 优惠商品(010) 常用商品(100)，三者同时存在111
     */
    PageVo<ProductVo> getPreferred(Integer preferredFlag, Integer userId, Integer pageNum, Integer pageSize);

    /**
     * 相关推荐-根据id
     */
    List<ProductVo> getRecommended(Integer productID);

    /**
     * 二手商品通过地址ID获取详细省市区
     */
     AddressVo getAddressInfo(Integer townId);

    /**
     * 二手商品数据保存操作
     */
    void saveSencondHandProduct(SeconHandProduct seconHandProduct);
}
